@@ -1,8 +1,16 @@
-## ----setup, include=FALSE------------------------------------------------
+## ---- include = FALSE----------------------------------------------------
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>"
+)
+
 library(dplyr)
 library(tidypredict)
 
 ## ------------------------------------------------------------------------
+library(tidypredict)
+library(dplyr)
+
 df <- mtcars %>%
   mutate(char_cyl = paste0("cyl", cyl)) %>%
   select(wt, char_cyl, am) 
@@ -11,7 +19,6 @@ model <- glm(am ~ wt + char_cyl, data = df, family = "binomial")
 
 ## ------------------------------------------------------------------------
 library(tidypredict)
-
 tidypredict_sql(model, dbplyr::simulate_mssql())
 
 ## ------------------------------------------------------------------------
@@ -20,7 +27,8 @@ df %>%
   head(10) 
 
 ## ------------------------------------------------------------------------
-parse_model(model)
+pm <- parse_model(model)
+str(pm, 2)
 
 ## ------------------------------------------------------------------------
 tidypredict_fit(model)
