@@ -1,6 +1,5 @@
 library(testthat)
 library(tidypredict)
-library(xgboost)
 library(purrr)
 library(dplyr)
 library(Cubist)
@@ -9,4 +8,6 @@ library(rlang)
 library(partykit)
 library(yaml)
 
+if (requireNamespace("xgboost", quietly = TRUE)) library(xgboost)
+
 test_check("tidypredict")
